package com.sztzjy.money_management.controller;

import com.sztzjy.money_management.annotation.AnonymousAccess;
import com.sztzjy.money_management.config.Constant;
import com.sztzjy.money_management.entity.ResourceCenter;
import com.sztzjy.money_management.entity.StuTrainingWithBLOBs;
import com.sztzjy.money_management.mapper.ResourceCenterMapper;
import com.sztzjy.money_management.mapper.StuTrainingMapper;
import com.sztzjy.money_management.service.ResourceCenterService;
import com.sztzjy.money_management.util.ResultEntity;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.core.io.FileSystemResource;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.List;

@RestController
@Api(tags = "资源相关")
@RequestMapping("api/ResourceController")
public class ResourceController {
    @Autowired
    ResourceCenterService resourceCenterService;
    @Autowired
    ResourceCenterMapper resourceCenterMapper;
    @Value("${file.path}")
    private String filePath;
    @Autowired
    StuTrainingMapper trainingMapper;

    //上传资源文件
    @PostMapping("uploadResource")
    @ApiOperation("上传资源文件")
    @AnonymousAccess
    public ResultEntity uploadResource(@RequestParam MultipartFile file,
                                       @ApiParam("学校id") @RequestParam String schoolId,
                                       @ApiParam("章节id") @RequestParam String chapterId,
                                       @ApiParam("上传文件类型 文件/视频") @RequestParam String type) {
        Boolean flag = resourceCenterService.uploadResource(file, schoolId,chapterId,type);
        if (flag) {
            return new ResultEntity<>(HttpStatus.OK, "新增成功");
        } else {
            return new ResultEntity<>(HttpStatus.BAD_REQUEST, "新增失败");
        }
    }


    //根据章节id查看资源文件列表
    @AnonymousAccess
    @GetMapping("selectResourceByChapterId")
    @ApiOperation("根据章节查看资源文件列表,图片资源使用默认图片")
    public ResultEntity<List<ResourceCenter>> selectResourceByChapterId(@ApiParam("学校id") String schoolId,
                                                                        @ApiParam("章节Id") @RequestParam String chapterId) {
        List<ResourceCenter> list = resourceCenterService.selectResourceByChapterId(schoolId, chapterId);
        return new ResultEntity(HttpStatus.OK, "根据章节查看资源文件列表，展示成功", list);
    }

    //删除资源
    @GetMapping("deleteResource")
    @ApiOperation("删除资源")
    @AnonymousAccess
    public ResponseEntity deleteResource(@ApiParam("资源ID") @RequestParam String resourceId, String schoolId){
        ResourceCenter resourceCenter = resourceCenterMapper.selectByPrimaryKey(resourceId);
        if(Constant.BUILT_IN_SCHOOL_ID.equals(schoolId)){
            resourceCenterMapper.deleteByPrimaryKey(resourceId);
            return new ResultEntity(HttpStatus.OK, "删除资源文件成功");
        }
        String schoolIdRC = resourceCenter.getSource();
        if(schoolIdRC.equals(schoolId)){
            resourceCenterMapper.deleteByPrimaryKey(resourceId);
            return new ResultEntity(HttpStatus.OK, "删除资源文件成功");
        }else {
            return new ResultEntity(HttpStatus.BAD_REQUEST, "权限不足");
        }
    }

    //查看资源文件
    @GetMapping("/getResource")
    @ApiOperation("查看资源文件")
    @AnonymousAccess
    public ResponseEntity<FileSystemResource> streamVideo(@RequestParam String resourceId, HttpServletResponse response) {
        ResourceCenter resourceCenter = resourceCenterMapper.selectByPrimaryKey(resourceId);
        String url = resourceCenter.getResourceUrl();
        String videoPath = filePath + url;
        File videoFile = new File(videoPath);
        if("视频".equals(resourceCenter.getType())){
            if (videoFile.exists()) {
                Path path = Paths.get(videoPath);
                FileSystemResource fileSystemResource = new FileSystemResource(videoFile);
                return ResponseEntity.ok()
                        .contentType(MediaType.parseMediaType("video/mp4"))
                        .body(fileSystemResource);
            } else {
                return ResponseEntity.notFound().build();
            }
        }else if("文件".equals(resourceCenter.getType())){
            if (videoFile.exists()) {
                Path path = Paths.get(videoPath);
                FileSystemResource fileSystemResource = new FileSystemResource(videoFile);
                if(url.endsWith("pptx")){
                    return ResponseEntity.ok()
                            .contentType(MediaType.parseMediaType("application/vnd.openxmlformats-officedocument.presentationml.presentation"))
                            .body(fileSystemResource);
                }else if(url.endsWith("ppt")){
                    return ResponseEntity.ok()
                            .contentType(MediaType.parseMediaType("application/vnd.ms-powerpoint"))
                            .body(fileSystemResource);
                }else {
                    return ResponseEntity.ok()
                            .contentType(MediaType.parseMediaType("application/pdf"))
                            .body(fileSystemResource);
                }
            } else {
                return ResponseEntity.notFound().build();
            }
        }
        return ResponseEntity.notFound().build();
    }

    //下载资源文件
    @GetMapping("downloadResource")
    @ApiOperation("下载资源文件")
    @AnonymousAccess
    public void downloadResource(@ApiParam("资源ID") @RequestParam String resourceId, HttpServletResponse response) {
        resourceCenterService.downloadResource(resourceId, response);
    }

    @AnonymousAccess
    @ApiOperation("设置资源学习时间（分钟）")  //获取之前的学习时间 并设置完成情况
    @PostMapping("setKnowledgeSummaryMinutes")
    public ResultEntity<String> getKnowledgeNote(@RequestParam String trainingId,@ApiParam("知识概要学习时间")@RequestParam Integer minutes) {
        StuTrainingWithBLOBs stuTrainingWithBLOBs = trainingMapper.selectByPrimaryKey(trainingId);
        Integer resourceLearningCompleteStatus = stuTrainingWithBLOBs.getResourceLearningCompleteStatus();
        if(resourceLearningCompleteStatus==null){
            stuTrainingWithBLOBs.setResourceLearningCompleteStatus(minutes);
        }else {
            stuTrainingWithBLOBs.setResourceLearningCompleteStatus(resourceLearningCompleteStatus+minutes);
        }
        trainingMapper.updateByPrimaryKeyWithBLOBs(stuTrainingWithBLOBs);
        return new ResultEntity<>(stuTrainingWithBLOBs.getKnowledgeNote());
    }



}
